@@ -5,14 +5,10 @@ for (var j = 0; j < desktopsArray.length; j++) {
 desktopsArray[0].addWidget("org.kde.phone.krunner", 0, 0, screenGeometry(0).width, 20)
 // keep this list in sync with shell/contents/updates/panelsfix.js
 var panel = new Panel("org.kde.phone.panel");
+panel.location = "top";
 panel.addWidget("org.kde.plasma.notifications");
 panel.addWidget("org.kde.plasma.mediacontroller");
 panel.height = 1 * gridUnit;
 
-var bottomPanel = new Panel("org.kde.phone.taskpanel");
+var bottomPanel = new Panel("org.kde.phone.taskpanel")
 bottomPanel.location = "bottom";
-
-if (screenGeometry(bottomPanel.screen).height > screenGeometry(bottomPanel.screen).width)
-    bottomPanel.height = 2 * gridUnit;
-else
-    bottomPanel.height = 1 * gridUnit;
